/*global define*/
/**
 * It holds the Spreedly express widget methods and translations.
 *
 * @class de_epages.spreedly.ui.express
 *
 * @uses jQuery
 * @uses ep
 *
 * @since 7.12.0
 *
 */
define('de_epages/spreedly/ui/express', [
    'jquery',
    '$dict!../dictionary',
    '$ready!'
], function ($, epDict) {
    'use strict';

    /*
     * @dictionary  de_epages.spreedly.dictionary
     *
     * @translation {SpreedlyExpressCloseLabel}
     *              {SpreedlyExpressNameLabel}
     *              {SpreedlyExpressNumberLabel}
     *              {SpreedlyExpressCVVLabel}
     *              {SpreedlyExpressExpirationLabel}
     *              {SpreedlyExpressSubmitLabel}
     */

    /**
     * @param {String}  SpreedlyEnvironmentKey  Spreedly environment Key string for Epages.
     * @param {Integer} ExpressAmount           Amount of money to be paid.
     * @param {String}  ShopName                Epages shop name.
     * @param {String}  ShopSlogan              Epages shop slogan.
     * @param {String}  UserFullName            End user full name.
     * @param {String}  PaymentMethodValue      Payment method value.
     * @param {String}  SubmitButtonId          Submit button identifier to open express widget.
     * @param {String}  BottomSubmitButtonId    Bottom submit button identifier to open express widget (only for mobile).
     */

    return function (
            SpreedlyEnvironmentKey,
            ExpressAmount,
            ShopName,
            ShopSlogan,
            UserFullName,
            PaymentMethodValue,
            SubmitButtonId,
            BottomSubmitButtonId
                    ) {

//      For mobile checkout, this script is run over different checkout phases, so we control when
//      the environment is ready to be run. This way we avoid javascript failures.
        var expressSubmitButton = document.getElementById(SubmitButtonId);
        if ( (expressSubmitButton == null) || (typeof expressSubmitButton == 'undefined') ) {
            return;
        }

//       Epages button launcher(s) on Spreedly Express widget are initially disabled, but they get enabled to be
//       clicked as soon as Spreedly widget is ready.
        function enableEpagesSubmitButton () {
            expressSubmitButton.disabled = false;
            var bottomExpressSubmitButton = document.getElementById(BottomSubmitButtonId);
            if ( (bottomExpressSubmitButton != null) && (typeof bottomExpressSubmitButton != 'undefined') ) {
                bottomExpressSubmitButton.disabled = false;
            }
        }
        
        function disableEpagesSubmitButton () {
            expressSubmitButton.disabled = true;
            var bottomExpressSubmitButton = document.getElementById(BottomSubmitButtonId);
            if ( (bottomExpressSubmitButton != null) && (typeof bottomExpressSubmitButton != 'undefined') ) {
                bottomExpressSubmitButton.disabled = true;
            }
        }

//      Initially Express window opening button is disabled till Spreedly has initialized the widget and informs us
//      through "onInit" method that everything is ready, so we enable it on this call.
        disableEpagesSubmitButton();
        SpreedlyExpress.onInit(enableEpagesSubmitButton);

//      Load data and label translations to Spreedly Express widget. Only credit card data remains pending.
        SpreedlyExpress.init(SpreedlyEnvironmentKey, {
            "amount": ExpressAmount,
            "company_name": ShopName,
            "sidebar_top_description": ShopSlogan,
            "full_name": UserFullName,
            "close_label": epDict.translate('{SpreedlyExpressCloseLabel}'),
            "name_label" : epDict.translate('{SpreedlyExpressNameLabel}'),
            "number_label" : epDict.translate('{SpreedlyExpressNumberLabel}'),
            "cvv_label" : epDict.translate('{SpreedlyExpressCVVLabel}'),
            "expiration_label" : epDict.translate('{SpreedlyExpressExpirationLabel}'),
            "submit_label" : epDict.translate('{SpreedlyExpressSubmitLabel}')
        });

//      Spreedly sends back required information after submitting express widget through "onPaymentMethod".
//      We collect required information and submit our own form to go to the next checkout step.
        SpreedlyExpress.onPaymentMethod(function(token, formData) {
            disableEpagesSubmitButton();
            var formSelector = $("#express-form");
            formSelector.prepend("<input type='hidden' name='PaymentMethod' value='" + PaymentMethodValue + "'>");
            formSelector.prepend("<input type='hidden' name='payment_method_token' value='" + token + "'>");
            formSelector.submit();
        });

    };
});